# arduino: parts

|   |   |   |   |   |   |   |   |   |   |
| --- | --- | --- | --- | --- | --- | --- | --- | --- | --- |
| [`Arduino Nano`](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/arduino-nano.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/arduino-nano.png?raw=true)](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/arduino-nano.md)  | [`HC-05/HC-06, Bluetooth module`](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/HC-05.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/HC-05-with-header-board-1.jpg?raw=true)](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/HC-05.md)  | [`HW-373, Li-Ion charger`](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/hw-373-charger.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/hw-373-charger.jpeg?raw=true)](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/hw-373-charger.md)  | [`LED, ~2 V forward voltage, 10-20 mA`](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/LED.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/led.png?raw=true)](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/LED.md) 2 x blue + 1 x RGB | [`Li-Ion battery`](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/li-ion-battery.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/lithium-battery.jpg?raw=true)](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/li-ion-battery.md) 18650, 3.6v, 3350mAh, with holder | [`MT-3608, step up module.`](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/mt-3608.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/mt-3608.jpg?raw=true)](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/mt-3608.md)  | [`Resistor, 1/4 watt, 5% tolerance`](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/resistor.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/resistor.png?raw=true)](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/resistor.md) 5 x 330 Ω | [`capacitor, 470 μF to 1000 μF, 16 V or 25 V, Electrolytic, 105 °C rated if possible.`](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/470-mF.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/capacitor.png?raw=true)](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/470-mF.md)  | [`double-sided PCB, 9 cm x 7 cm`](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/PCB-double-9x7.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/PCB-double-9x7.jpeg?raw=true)](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/PCB-double-9x7.md)  | [`dupont cables, female to female`](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/dupont-cables.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/dupont-cables.jpg?raw=true)](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/dupont-cables.md) 10 cm |
| [`nuts, bolts, and spacers`](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/nuts-bolts-spacers.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/nuts-bolts-spacers.jpg?raw=true)](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/nuts-bolts-spacers.md) M3: (4 x bolt + 4 x nut + 8 x 25 mm spacer) | [`on/off DC switch with indicator led`](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/dc-switch.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/on-off-switch.png?raw=true)](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/dc-switch.md) small | [`pin headers`](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/pin-headers.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/pin-headers.jpg?raw=true)](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/pin-headers.md) 2 x (male header, 1 x 40) | [`plexiglass, 2 mm or 2.5 mm thickness`](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/plexiglass.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/plexiglass.jpg?raw=true)](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/plexiglass.md) 2 x 9 cm x 7 cm | [`potentiometer`](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/potentiometer.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/potentiometer.jpeg?raw=true)](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/potentiometer.md) 10 kΩ | [`push button`](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/pushbutton.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/pushbutton.png?raw=true)](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/pushbutton.md) 1 |  |  |  |  |

1. [Arduino Nano](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/arduino-nano.md).
1. [HC-05/HC-06, Bluetooth module](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/HC-05.md).
1. [HW-373, Li-Ion charger](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/hw-373-charger.md).
1. [LED, ~2 V forward voltage, 10-20 mA](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/LED.md): 2 x blue + 1 x RGB.
1. [Li-Ion battery](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/li-ion-battery.md): 18650, 3.6v, 3350mAh, with holder.
1. [MT-3608, step up module.](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/mt-3608.md).
1. [Resistor, 1/4 watt, 5% tolerance](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/resistor.md): 5 x 330 Ω.
1. [capacitor, 470 μF to 1000 μF, 16 V or 25 V, Electrolytic, 105 °C rated if possible.](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/470-mF.md).
1. [double-sided PCB, 9 cm x 7 cm](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/PCB-double-9x7.md).
1. [dupont cables, female to female](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/dupont-cables.md): 10 cm.
1. [nuts, bolts, and spacers](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/nuts-bolts-spacers.md): M3: (4 x bolt + 4 x nut + 8 x 25 mm spacer).
1. [on/off DC switch with indicator led](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/dc-switch.md): small.
1. [pin headers](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/pin-headers.md): 2 x (male header, 1 x 40).
1. [plexiglass, 2 mm or 2.5 mm thickness](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/plexiglass.md): 2 x 9 cm x 7 cm.
1. [potentiometer](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/potentiometer.md): 10 kΩ.
1. [push button](https://github.com/kamangir/bluer-sbc/tree/main/bluer_sbc/docs/parts/pushbutton.md): 1.
